<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_MX">
<context>
    <name>CompletingEdit</name>
    <message>
        <source>Jump to PDF</source>
        <translation>Pasar al PDF</translation>
    </message>
    <message>
        <source>No suggestions</source>
        <translation>No hay sugerencias</translation>
    </message>
    <message>
        <source>Ignore word</source>
        <translation>Ignorar palabra</translation>
    </message>
</context>
<context>
    <name>ConfirmDelete</name>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Unable to delete</source>
        <translation>Imposible eliminar</translation>
    </message>
    <message>
        <source>Some of the auxiliary files could not be removed. Perhaps you don&apos;t have permission to delete them.</source>
        <translation>Algunos archivos auxiliares no se puedieron eliminar. Probablemente no cuenta con los permisos requeridos.</translation>
    </message>
    <message>
        <source>Confirm file deletion</source>
        <translation>Confirmar eliminación del archivo</translation>
    </message>
    <message>
        <source>Auxiliary files to be deleted:</source>
        <translation>Archivos auxiliares que se van a eliminar:</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Seleccionar todo</translation>
    </message>
    <message>
        <source>Select None</source>
        <translation>Deshacer selección</translation>
    </message>
    <message>
        <source>Toggle</source>
        <translation>Invertir selección</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Find</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Find:</source>
        <translation>Buscar:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>&amp;Buscar en todo el documento</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>Buscar &amp;hacia atrás</translation>
    </message>
    <message>
        <source>Search within &amp;selection</source>
        <translation>Buscar en la parte &amp;seleccionada</translation>
    </message>
    <message>
        <source>Find &amp;all occurrences</source>
        <translation>Hallar &amp;todos los casos</translation>
    </message>
    <message>
        <source>Search all &amp;open files</source>
        <translation>Buscar en los &amp;archivos abiertos</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>&amp;Diferenciar mayúsculas/minúsculas</translation>
    </message>
    <message>
        <source>W&amp;hole words</source>
        <translation>&amp;Palabras completas</translation>
    </message>
    <message>
        <source>&amp;Regular expression</source>
        <translation>&amp;Expresión regular</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>No hay búsqueda reciente</translation>
    </message>
    <message>
        <source>(invalid)</source>
        <translation>(error)</translation>
    </message>
</context>
<context>
    <name>HardWrapDialog</name>
    <message>
        <source>Hard Wrap</source>
        <translation>Ajuste de líneas</translation>
    </message>
    <message>
        <source>Wrap lines to:</source>
        <translation>Ajuste de líneas:</translation>
    </message>
    <message>
        <source>Current window size</source>
        <translation>Tamaño de la ventana actual</translation>
    </message>
    <message>
        <source>Line length:</source>
        <translation>Tamaño de línea:</translation>
    </message>
    <message>
        <source>Re-wrap paragraphs</source>
        <translation>Reformatear parágrafos</translation>
    </message>
    <message>
        <source>Unwrap</source>
        <translation>Desajustar líneas</translation>
    </message>
</context>
<context>
    <name>PDFDocument</name>
    <message>
        <source>Open Recent</source>
        <translation>Abrir reciente</translation>
    </message>
    <message>
        <source>Failed to load file &quot;%1&quot;; perhaps it is not a valid PDF document.</source>
        <translation>Error al abrir el archivo &quot;%1&quot;; tal vez no es un archivo PDF válido.</translation>
    </message>
    <message>
        <source>No SyncTeX data available</source>
        <translation>No hay información SyncTeX disponible</translation>
    </message>
    <message>
        <source>SyncTeX: &quot;%1&quot;</source>
        <translation>SyncTeX: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>%1[*] - %2</source>
        <translation>%1[*] - %2</translation>
    </message>
    <message>
        <source>page %1 of %2</source>
        <translation>página %1 de %2</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
    <message>
        <source>Unfortunately, this version of %1 is unable to print Pdf documents due to various technical reasons.
</source>
        <translation>Lo sentimos. Esta versión de %1 es incapaz de imprimir documentos PDF por varias razones técnicas.</translation>
    </message>
    <message>
        <source>Do you want to open the file in the default viewer for printing instead?</source>
        <translation>¿Prefiere utilizar el programa lector de PDF predeterminado para imprimir este archivo?</translation>
    </message>
    <message>
        <source> (remember to close it again to avoid access problems)</source>
        <translation> (No olvide cerrar luego dicho programa para evitar problemas de acceso)</translation>
    </message>
    <message>
        <source>untitled.pdf[*]</source>
        <translation>texto.pdf[*]</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Archivo</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Ventana</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Exhibir</translation>
    </message>
    <message>
        <source>Typeset</source>
        <translation>Compilar</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Barra de herramientas</translation>
    </message>
    <message>
        <source>About TeXworks...</source>
        <translation>Acerca de TeXworks...</translation>
    </message>
    <message>
        <source>First Page</source>
        <translation>Primera página</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Página anterior</translation>
    </message>
    <message>
        <source>Ctrl+PgUp</source>
        <comment>shortcut key name, do not translate</comment>
        <translation>Ctrl+PgUp</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Página siguiente</translation>
    </message>
    <message>
        <source>Ctrl+PgDown</source>
        <comment>shortcut key name, do not translate</comment>
        <translation>Ctrl+PgDown</translation>
    </message>
    <message>
        <source>Last Page</source>
        <translation>Última página</translation>
    </message>
    <message>
        <source>Go to Page...</source>
        <translation>Saltar a la página...</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Ampliar</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Scripts</translation>
    </message>
    <message>
        <source>Scripting TeXworks</source>
        <translation>Scripts de TeXworks</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Reducir</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>Ajustar a la ventana</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <source>Actual Size</source>
        <translation>Tamaño natural</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>Ajustar a lo ancho</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nuevo</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Abrir...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Deshacer</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Rehacer</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Z</source>
        <translation>Ctrl+Shift+Z</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
    <message>
        <source>Ctrl+Backspace</source>
        <translation>Ctrl+Backspace</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Preferencias...</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Cascada</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>Mosaico</translation>
    </message>
    <message>
        <source>Go to Source</source>
        <translation>Código fuente</translation>
    </message>
    <message>
        <source>Ctrl+&apos;</source>
        <translation>Ctrl+&apos;</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>Nuevo a partir de Plantilla...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>Full Screen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Ctrl+Shift+F</source>
        <translation>Ctrl+Shift+F</translation>
    </message>
    <message>
        <source>Magnify</source>
        <translation>Ampliar</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>Desplazar</translation>
    </message>
    <message>
        <source>Select Text</source>
        <translation>Seleccionar texto</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>Seleccionar imagen</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>Página oficial de TeXworks</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>Escribir a la lista de usuarios</translation>
    </message>
    <message>
        <source>Side by Side</source>
        <translation>Lado a Lado</translation>
    </message>
    <message>
        <source>Place on Left</source>
        <translation>Colocar a la izquierda</translation>
    </message>
    <message>
        <source>Place on Right</source>
        <translation>Colocar a la derecha</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>Salir de TeXworks</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Find Again</source>
        <translation>Continuar búsqueda</translation>
    </message>
    <message>
        <source>Reload Script List</source>
        <translation>Actualizar lista de scripts</translation>
    </message>
    <message>
        <source>Print Pdf...</source>
        <translation>Imprimir PDF...</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation>Administrar Scripts</translation>
    </message>
    <message>
        <source>Show Scripts Folder</source>
        <translation>Carpeta de Scripts</translation>
    </message>
    <message>
        <source>About Scripts...</source>
        <translation>Acerca de Scripts...</translation>
    </message>
    <message>
        <source>Find...</source>
        <translation>Buscar...</translation>
    </message>
    <message>
        <source>Typeset</source>
        <comment>menu title</comment>
        <translation>Compilar</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <comment>action</comment>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Abort typesetting</source>
        <translation>Interrumpir compilación</translation>
    </message>
    <message>
        <source>Settings and Resources...</source>
        <translation>Configuración y Recursos ...</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>Limpiar lista de archivos recientes</translation>
    </message>
    <message>
        <source>Error initializing SyncTeX</source>
        <translation>Error al iniciar SyncTeX</translation>
    </message>
    <message>
        <source>Go to previous view</source>
        <translation></translation>
    </message>
    <message>
        <source>Alt+Left</source>
        <translation>Alt+Left</translation>
    </message>
    <message>
        <source>Single Page</source>
        <translation>Página por separado</translation>
    </message>
    <message>
        <source>Single Page Continuous</source>
        <translation>Página continua</translation>
    </message>
    <message>
        <source>Two Pages Continuous</source>
        <translation>Dos páginas continuas</translation>
    </message>
    <message>
        <source>Jump to Source</source>
        <translation>Código fuente</translation>
    </message>
    <message>
        <source>Go to Page</source>
        <translation>Saltar a la página</translation>
    </message>
    <message>
        <source>Page number:</source>
        <translation>Número de página:</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translatorcomment>Abrir URL</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <source>You are in the process of opening the URL %1. Opening unknown or untrusted web adresses can be a security risk.
Do you want to continue?</source>
        <translation>Intenta acceder a la URL %1. Abrir sitios web desconocidos o no confiables puede ser un riesgo para la seguridad.
¿Desea continuar?</translation>
    </message>
    <message>
        <source>Custom...</source>
        <translatorcomment>Personalizar...</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <source>Set Zoom</source>
        <translatorcomment>Establecer ampliación</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <source>Zoom level:</source>
        <translation>Ampliación:</translation>
    </message>
</context>
<context>
    <name>PDFFindDialog</name>
    <message>
        <source>Find</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>Ninguna búsqueda reciente</translation>
    </message>
    <message>
        <source>Find in PDF</source>
        <translation>Buscar en el archivo PDF</translation>
    </message>
    <message>
        <source>Find:</source>
        <translation>Buscar:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>&amp;Buscar en todo el documento</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>Buscar &amp;hacia atrás</translation>
    </message>
    <message>
        <source>Find &amp;all occurrences</source>
        <translation>Hallar &amp;todos los casos</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>&amp;Diferenciar mayúsculas/minúsculas</translation>
    </message>
    <message>
        <source>&amp;Sync to source</source>
        <translation>&amp;Sincronizar con código fuente</translation>
    </message>
</context>
<context>
    <name>PrefsDialog</name>
    <message>
        <source>Choose Directory</source>
        <translation>Seleccionar directorio</translation>
    </message>
    <message>
        <source>New Tool</source>
        <translation>Nueva herramienta</translation>
    </message>
    <message>
        <source>System default [%1]</source>
        <translation>Idioma del sistema [%1]</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>TeXworks Preferences</source>
        <translation>Preferencias de TeXworks</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Small icons</source>
        <translation>Iconos pequeños</translation>
    </message>
    <message>
        <source>Medium icons</source>
        <translation>Iconos medianos</translation>
    </message>
    <message>
        <source>Large icons</source>
        <translation>Iconos grandes</translation>
    </message>
    <message>
        <source>Show text as well as icons</source>
        <translation>Mostrar texto e iconos</translation>
    </message>
    <message>
        <source>When launched, show</source>
        <translation>Al inicio, abrir</translation>
    </message>
    <message>
        <source>New blank document</source>
        <translation>Nuevo documento vacío</translation>
    </message>
    <message>
        <source>Template selection dialog</source>
        <translation>Caja de diálogo para seleccionar Plantilla</translation>
    </message>
    <message>
        <source>File Open dialog</source>
        <translation>Caja de diálogo para seleccionar Archivo</translation>
    </message>
    <message>
        <source>Editor</source>
        <translation>Editor</translation>
    </message>
    <message>
        <source>Editor defaults</source>
        <translation>Valores predeterminados del editor</translation>
    </message>
    <message>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <source>Tab width:</source>
        <translation>Tamaño de Tab:</translation>
    </message>
    <message>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <source>Wrap lines</source>
        <translation>Ajuste automático de líneas</translation>
    </message>
    <message>
        <source>Syntax coloring:</source>
        <translation>Resaltar sintaxis:</translation>
    </message>
    <message>
        <source>Auto-Indent mode:</source>
        <translation>Modo de sangrado automático:</translation>
    </message>
    <message>
        <source>Smart Quotes mode:</source>
        <translation>Modo para marcas automáticas:</translation>
    </message>
    <message>
        <source>Spell-check language:</source>
        <translation>Idioma para corregir ortografía:</translation>
    </message>
    <message>
        <source>Encoding:</source>
        <translation>Codificación:</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Previsualizar</translation>
    </message>
    <message>
        <source>Default scaling</source>
        <translation>Escala predeterminada</translation>
    </message>
    <message>
        <source>Actual size</source>
        <translation>Tamaño natural</translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>Ajustar a lo ancho</translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>Ajustar a la ventana</translation>
    </message>
    <message>
        <source>Fixed scale:</source>
        <translation>Escala fija:</translation>
    </message>
    <message>
        <source> %</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Magnifying glass</source>
        <translation>Lente de aumento</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Pequeño</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mediano</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Grande</translation>
    </message>
    <message>
        <source>Circular magnifier</source>
        <translation>Lupa</translation>
    </message>
    <message>
        <source>Screen resolution:</source>
        <translation>Resolución de pantalla:</translation>
    </message>
    <message>
        <source> dpi</source>
        <translation type="obsolete"> dpi</translation>
    </message>
    <message>
        <source>Typesetting</source>
        <translation>Compilación</translation>
    </message>
    <message>
        <source>Paths for TeX and related programs</source>
        <translation>Ubicación de TeX y programas relativos</translation>
    </message>
    <message>
        <source>Processing tools</source>
        <translation>Herramientas para procesamiento</translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation>Editar...</translation>
    </message>
    <message>
        <source>Default:</source>
        <translation>Predeterminada:</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Scripts</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Seguridad</translation>
    </message>
    <message>
        <source>Allow scripts to read all files (script and document files are always readable)</source>
        <translation>Permitir a los scripts leer todos los archivos 
	(que tanto el script como el documento se puedan leer)</translation>
    </message>
    <message>
        <source>Allow scripts to write files</source>
        <translation>Permitir a los scripts escribir en los archivos</translation>
    </message>
    <message>
        <source>Enable plug-in scripting languages (may circumvent other restrictions on script behavior)</source>
        <translation>Habilitar lenguajes de script mediante módulos plugin 
	(puede eludir otras restricciones sobre el comportamiento de los scripts)</translation>
    </message>
    <message>
        <source>Debugging</source>
        <translation>Depuración</translation>
    </message>
    <message>
        <source>Enable QtScript debugger</source>
        <translation>Habilitar el depurador QtScript</translation>
    </message>
    <message>
        <source>Allow scripts to run system commands</source>
        <translation>Autorizar que los scripts puedan ejecutar comandos del sistema</translation>
    </message>
    <message>
        <source>Line numbers</source>
        <translation>Número de línea</translation>
    </message>
    <message>
        <source>Global editor options</source>
        <translation>Parámetros globales del editor</translation>
    </message>
    <message>
        <source>Highlight current line</source>
        <translation>Resaltar la línea actual</translation>
    </message>
    <message>
        <source>Never</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translation>Nunca</translation>
    </message>
    <message>
        <source>Automatically</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translation>Automáticamente</translation>
    </message>
    <message>
        <source>On success</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translation>En caso de éxito</translation>
    </message>
    <message>
        <source>&lt;em&gt;Note:&lt;/em&gt; These are default settings. Changes to them will not affect windows that are already open. Use the respective items in the &amp;quot;Format&amp;quot; menu to achieve that.</source>
        <translation>&lt;em&gt;Nota: &lt;/em&gt; Estos son los valores predeterminados de la configuración. Los cambios que realice en ellos no afectarán las ventanas que haya abierto. Válgase de los elementos correspondientes en el menú &amp;quot;Formato&amp;quot; para conseguir dicho propósito.</translation>
    </message>
    <message>
        <source>Enable autocompletion</source>
        <translation>Activar autocompletado</translation>
    </message>
    <message>
        <source>Hide console output:</source>
        <translation>Ocultar la consola de salida:</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;strong&gt;Never:&lt;/strong&gt; Never hide the console output panel after typesetting.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;Automatically:&lt;/strong&gt; Hide the console output panel after successful typesetting, but only if it was hidden before.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;On Success:&lt;/strong&gt; Hide the console output panel after successful typesetting, regardless of its previous state.&lt;/p&gt;
</source>
        <translation>&lt;p&gt;&lt;strong&gt;Nunca: &lt;/strong&gt;No ocultar nunca la consola de salida después de cada compilación.&lt;/p&gt;

&lt;p&gt;&lt;strong&gt;Automáticamente: &lt;/strong&gt;Efectuada la compilación correctamente, ocultar la consola de salida sólo si ésta estaba oculta antes.&lt;/p&gt;

&lt;p&gt;&lt;strong&gt;En caso de éxito: &lt;/strong&gt;Si la compilación ocurre sin contratiempos, ocultar la consola de salida sin importar su estado anterior.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfaz</translation>
    </message>
    <message>
        <source>Locale:</source>
        <translation>Idioma:</translation>
    </message>
    <message>
        <source>Toolbar buttons:</source>
        <translation>Botones de la barra de herramientas:</translation>
    </message>
    <message>
        <source>Open corresponding PDF preview with TeX files</source>
        <translation>Mostrar el PDF asociado a cada archivo TeX </translation>
    </message>
    <message>
        <source>Page mode:</source>
        <translation>Modo de exhibir las páginas:</translation>
    </message>
    <message>
        <source>Single Page</source>
        <translation>Página por separado</translation>
    </message>
    <message>
        <source>Single Page Continuous</source>
        <translation>Página continua</translation>
    </message>
    <message>
        <source>Two Page Continuous</source>
        <translation>Dos páginas continuas</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>TeX documents (*.tex)</source>
        <translation>Documentos TeX (*.tex)</translation>
    </message>
    <message>
        <source>LaTeX documents (*.ltx)</source>
        <translation>Documentos LaTeX (*.ltx)</translation>
    </message>
    <message>
        <source>BibTeX databases (*.bib)</source>
        <translation>Bases de datos BibTeX (*.bib)</translation>
    </message>
    <message>
        <source>Style files (*.sty)</source>
        <translation>Archivos de estilo (*.sty)</translation>
    </message>
    <message>
        <source>Class files (*.cls)</source>
        <translation>Archivos de clase (*.cls)</translation>
    </message>
    <message>
        <source>Documented macros (*.dtx)</source>
        <translation>Macros documentadas (*.dtx)</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation>Archivos de texto (*.txt)</translation>
    </message>
    <message>
        <source>PDF documents (*.pdf)</source>
        <translation>Documentos PDF (*.pdf)</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Todos los archivos</translation>
    </message>
    <message>
        <source>Log files (*.log *.blg)</source>
        <translation>Archivos Log (*.log *.blg)</translation>
    </message>
    <message>
        <source>Auxiliary files (*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.brf)</source>
        <translation>Archivos auxiliares (*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.brf)</translation>
    </message>
</context>
<context>
    <name>ReplaceDialog</name>
    <message>
        <source>Replace</source>
        <translation>Reemplazar</translation>
    </message>
    <message>
        <source>Replace All</source>
        <translation>Reemplazar todos</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>Ninguna búsqueda reciente</translation>
    </message>
    <message>
        <source>No recent replacement strings</source>
        <translation>Ninguna cadena de sustitución reciente</translation>
    </message>
    <message>
        <source>(invalid)</source>
        <translation>(error)</translation>
    </message>
    <message>
        <source>Replace:</source>
        <translation>Reemplazar:</translation>
    </message>
    <message>
        <source>With:</source>
        <translation>Por:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>&amp;Buscar en todo el documento</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>Buscar &amp;hacia atrás</translation>
    </message>
    <message>
        <source>Replace within &amp;selection</source>
        <translation>Reemplazar en la parte &amp;seleccionada </translation>
    </message>
    <message>
        <source>Replace in all &amp;open files</source>
        <translation>Reemplazar en los &amp;archivos abiertos</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>&amp;Diferenciar mayúsculas/minúsculas</translation>
    </message>
    <message>
        <source>W&amp;hole words</source>
        <translation>&amp;Palabras completas</translation>
    </message>
    <message>
        <source>&amp;Regular expression</source>
        <translation>&amp;Expresión regular</translation>
    </message>
</context>
<context>
    <name>ResourcesDialog</name>
    <message>
        <source>TeXworks Settings and Resources</source>
        <translation>TeXworks: Configuración y Recursos</translation>
    </message>
    <message>
        <source>Storage Locations</source>
        <translation>Localización</translation>
    </message>
    <message>
        <source>Settings:</source>
        <translation>Configuración:</translation>
    </message>
    <message>
        <source>Resources:</source>
        <translation>Recursos:</translation>
    </message>
    <message>
        <source>Registry (%1)</source>
        <translation>Registro (%1)</translation>
    </message>
</context>
<context>
    <name>ScreenCalibrationWidget</name>
    <message>
        <source>Drag the ruler or change the value to match real world lengths.
Common paper sizes are marked as well (you may need to resize the dialog window to see them).
Use the context menu to change the units.</source>
        <translation>Arrastre la regla o cambie los valores para hacerlos coincidir con las longitudes reales.
Los tamaños de papel más comunes aparecen marcados (puede que deba cambiar el tamaño de la ventana de diálogo para verlos).
Utilice el menú contextual para modificar las unidades.</translation>
    </message>
    <message>
        <source> dpi</source>
        <extracomment>dots per inch</extracomment>
        <translatorcomment>.dpi</translatorcomment>
        <translation> dpi</translation>
    </message>
    <message>
        <source>DIN A4</source>
        <translation>DIN A4</translation>
    </message>
    <message>
        <source>Letter</source>
        <translation>Tamaño carta</translation>
    </message>
    <message>
        <source>cm</source>
        <extracomment>this refers to the length unit of centimeters</extracomment>
        <translatorcomment>cm</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <source>in</source>
        <extracomment>this refers to the length unit of inches</extracomment>
        <translatorcomment>pulg.</translatorcomment>
        <translation></translation>
    </message>
</context>
<context>
    <name>ScriptManager</name>
    <message>
        <source>Name: </source>
        <translation>Nombre: </translation>
    </message>
    <message>
        <source>Context: </source>
        <translation>Contexto: </translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Descripción: </translation>
    </message>
    <message>
        <source>Author: </source>
        <translation>Аutor: </translation>
    </message>
    <message>
        <source>Version: </source>
        <translation>Versión: </translation>
    </message>
    <message>
        <source>Shortcut: </source>
        <translation>Atajo: </translation>
    </message>
    <message>
        <source>File: </source>
        <translation>Archivo: </translation>
    </message>
    <message>
        <source>Language: </source>
        <translation>Lenguaje: </translation>
    </message>
    <message>
        <source>Hook: </source>
        <translation>Gancho: </translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation>Administrar Scripts</translation>
    </message>
    <message>
        <source>Hook Scripts</source>
        <translation>Scripts gancho</translation>
    </message>
    <message>
        <source>Standalone Scripts</source>
        <translation>Scripts autónomos</translation>
    </message>
</context>
<context>
    <name>SearchResults</name>
    <message>
        <source>Search Results - %1 (%2 found)</source>
        <translation>Resultados de la búsqueda - %1 (%2 encontrados)</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Archivo</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Línea</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Inicio</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Search Results</source>
        <translation>Resultados de la búsqueda</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
<context>
    <name>TWApp</name>
    <message>
        <source>File</source>
        <translation>Archivo</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nuevo</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>Nuevo a partir de Plantilla...</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Preferencias...</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Abrir...</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>Abrir reciente</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>About </source>
        <translation>Acerca de </translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>Página ofical de TeXworks</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>Escribir a la lista de usuarios</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 is a simple environment for editing, typesetting, and previewing TeX documents.&lt;/p&gt;</source>
        <translation>&lt;p&gt;%1 es un simple recurso para editar, compilar y previsualizar documentos TeX.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://poppler.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; PDF rendering library by Kristian H&amp;#xF8;gsberg, Albert Astals Cid and others.</source>
        <translation>&lt;br&gt;&lt;a href=&quot;http://poppler.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; es la biblioteca para el renderizado PDF, obra de Kristian H&amp;#xF8;gsberg, Albert Astals Cid y colegas.</translation>
    </message>
    <message>
        <source>&lt;br&gt;Concept and resources from &lt;a href=&quot;http://www.uoregon.edu/~koch/texshop/&quot;&gt;TeXShop&lt;/a&gt; by Richard Koch.</source>
        <translation>&lt;br&gt;Ideas y recursos inspirados por &lt;a href=&quot;http://www.uoregon.edu/~koch/texshop/&quot;&gt;TeXShop&lt;/a&gt;, cuyo autor es Richard Koch.</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://itexmac.sourceforge.net/SyncTeX.html&quot;&gt;SyncTeX&lt;/a&gt; technology by J&amp;#xE9;r&amp;#xF4;me Laurens.</source>
        <translation>&lt;br&gt;Tecnología &lt;a href=&quot;http://itexmac.sourceforge.net/SyncTeX.html&quot;&gt;SyncTeX&lt;/a&gt; creada por J&amp;#xE9;r&amp;#xF4;me Laurens.</translation>
    </message>
    <message>
        <source>&lt;br&gt;Some icons used are from the &lt;a href=&quot;http://tango.freedesktop.org/&quot;&gt;Tango Desktop Project&lt;/a&gt;.</source>
        <translation>&lt;br&gt;Algunos iconos han sido tomados del &lt;a href=&quot;http://tango.freedesktop.org/&quot;&gt;Tango Desktop Project&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 translation kindly contributed by %2.</source>
        <translation>&lt;p&gt;Traducción al %1 realizada por %2.</translation>
    </message>
    <message>
        <source>[language name]</source>
        <translation>español</translation>
    </message>
    <message>
        <source>[translator&apos;s name/email]</source>
        <translation>Luis Montgomery Antelo/monty.luis@gmail.com</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>Acerca de %1</translation>
    </message>
    <message>
        <source>Unable to access &quot;%1&quot;; perhaps your browser or mail application is not properly configured?</source>
        <translation>No se pudo acceder a &quot;%1&quot;; ¿podría verificar la configuración de su navegador o cliente de correos?</translation>
    </message>
    <message>
        <source>Unable to create window</source>
        <translation>Falló creación de ventana</translation>
    </message>
    <message>
        <source>Something is badly wrong; %1 was unable to create a document window. The application will now quit.</source>
        <translation>Ha ocurrido un error grave; %1 no se ha podido crear la ventana para el documento. El programa se va a cerrar enseguida.</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir archivo</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Guardar archivo</translation>
    </message>
    <message>
        <source>No default binary directory found</source>
        <translation>No se encontró el directorio predeterminado con lo binarios respectivos</translation>
    </message>
    <message>
        <source>None of the predefined directories for TeX-related programs could be found.&lt;p&gt;&lt;small&gt;To run any processes, you will need to set the binaries directory (or directories) for your TeX distribution using the Typesetting tab of the Preferences dialog.&lt;/small&gt;</source>
        <translation>Ninguno de los directorios predefinidos con los programas TeX correspondientes se pudo encontrar.&lt;p&gt;&lt;small&gt; Para ejecutar cualquier proceso debe establecer la ubicación del directorio (o directorios) con los programas de su distribución TeX, utilizando la pestaña Compilar en la ventana de Preferencias.&lt;/small&gt;</translation>
    </message>
    <message>
        <source>Unable to find help file.</source>
        <translation>No se encontró el archivo de ayuda.</translation>
    </message>
    <message>
        <source>Permission request</source>
        <translation>Solicitud de permisos</translation>
    </message>
    <message>
        <source>The script &quot;%1&quot; is trying to open the file &quot;%2&quot; without sufficient permissions. Do you want to open the file?</source>
        <translation>El script &quot;%1&quot; intenta abrir el archivo &quot;%2&quot; sin contar con los permisos
necesarios. ¿Quiere abrirlo de todos modos?</translation>
    </message>
    <message>
        <source>&lt;p&gt;Distributed under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl-2.0.html&quot;&gt;GNU General Public License&lt;/a&gt;, version 2 or (at your option) any later version.</source>
        <translation>&lt;p&gt;Se distribuye protegido por la &lt;a href=&quot;http://www.gnu.org/licenses/gpl-2.0.html&quot;&gt; Licencia Pública General de GNU &lt;/a&gt;, versión 2 o (a su elección) cualquier versión posterior.</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>Limpiar la lista de archivos recientes</translation>
    </message>
    <message>
        <source>&lt;br&gt;Version %1 (%2) [r.%3, %4]</source>
        <translation>&lt;br&gt;Versión %1 (%2) [r.%3, %4]</translation>
    </message>
    <message>
        <source>&lt;br&gt;Version %1 (%2)</source>
        <translation>o&lt;br&gt;Versión %1 (%2)</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>Salir de TeXworks</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;a href=&quot;http://www.qt.io/&quot;&gt;Qt application framework&lt;/a&gt; v%1 by The Qt Company.</source>
        <translation>&lt;p&gt;&lt;a href=&quot;http://www.qt.io/&quot;&gt;Plataforma de desarrollo de aplicaciones Qt&lt;/a&gt; v%1 de The Qt Company.</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://hunspell.github.io/&quot;&gt;Hunspell&lt;/a&gt; spell checker by L&amp;#xE1;szl&amp;#xF3; N&amp;#xE9;meth.</source>
        <translation>&lt;br&gt;&lt;a href=&quot;http://hunspell.github.io/&quot;&gt;Hunspell&lt;/a&gt; es un corrector ortográfico creado por  L&amp;#xE1;szl&amp;#xF3; N&amp;#xE9;meth.</translation>
    </message>
</context>
<context>
    <name>TWScriptAPI</name>
    <message>
        <source>Internal error</source>
        <translation>Error interno</translation>
    </message>
    <message>
        <source>Failed to execute system command: %1</source>
        <translation>Ha fallado la ejecución del comando de sistema: %1</translation>
    </message>
    <message>
        <source>Error executing system command: %1</source>
        <translation>Error de ejecución del comando de sistema: %1</translation>
    </message>
    <message>
        <source>System command execution is disabled (see Preferences)</source>
        <translation>La ejecución de comandos del sistema está deshabilitada (véase Preferencias)</translation>
    </message>
    <message>
        <source>&quot;%1&quot; could not be opened.</source>
        <translation>&quot;%1&quot; no se puede abrir.</translation>
    </message>
    <message>
        <source>Reading all files is disabled (see Preferences)</source>
        <translation>La lectura de archivos está deshabilitada (véase Preferencias)</translation>
    </message>
    <message>
        <source>The file &quot;%1&quot; could not be opened for reading</source>
        <translation>El archivo &quot;%1&quot; no se puede abrir para lectura</translation>
    </message>
</context>
<context>
    <name>TWScriptable</name>
    <message>
        <source>Script result</source>
        <translation>Resultado del script</translation>
    </message>
    <message>
        <source>unknown error</source>
        <translation>error desconocido</translation>
    </message>
    <message>
        <source>Scripts may be used to add new commands to %1, and to extend or modify its behavior.</source>
        <translation>Los Scripts pueden usarse para añadir nuevas instrucciones a %1, y así ampliar o modificar su funcionalidad.</translation>
    </message>
    <message>
        <source>For more information on creating and using scripts, see %1&lt;/p&gt;</source>
        <translation>Para mayor información acerca de la creación y el uso de Scripts, véase %1&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Scripting languages currently available in this copy of %1:</source>
        <translation>Lenguajes de script disponibles en esta versión de %1:</translation>
    </message>
    <message>
        <source>About Scripts</source>
        <translation>Acerca de Scripts</translation>
    </message>
    <message>
        <source>Script &quot;%1&quot;: %2</source>
        <translation>Script &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <source>Script error</source>
        <translation>Error en el script</translation>
    </message>
    <message>
        <source>(disabled in the preferences)</source>
        <extracomment>This string is appended to a script language name to indicate it is currently disabled</extracomment>
        <translation>(deshabilitado en Preferencias)</translation>
    </message>
</context>
<context>
    <name>TWSystemCmd</name>
    <message>
        <source>ERROR: failure code %1</source>
        <translation>ERROR: falla en el código de %1</translation>
    </message>
    <message>
        <source>ERROR: exit code %1</source>
        <translation>ERROR: salida del código de %1</translation>
    </message>
</context>
<context>
    <name>TagsDock</name>
    <message>
        <source>Tags</source>
        <translation>Etiquetas</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Marcadores</translation>
    </message>
    <message>
        <source>Outline</source>
        <translation>Esquema</translation>
    </message>
    <message>
        <source>No tags</source>
        <translation>Sin etiquetas</translation>
    </message>
</context>
<context>
    <name>TeXDocument</name>
    <message>
        <source>New document</source>
        <translation>Nuevo documento</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>Abrir reciente</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir archivo</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Guardar archivo</translation>
    </message>
    <message>
        <source>The document &quot;%1&quot; has been modified.
Do you want to save your changes?</source>
        <translation>El documento &quot;%1&quot; ha sido modificado.
¿Desea conservar los cambios?</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <comment>shortcut: Don&apos;t Save</comment>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Do you want to discard all changes to the document &quot;%1&quot;, and revert to the last saved version?</source>
        <translation>¿Desea descartar todos los cambios que ha efectuado en el documento &quot;%1&quot; y volver a la última versión que se ha conservado?</translation>
    </message>
    <message>
        <source>Revert</source>
        <translation>Deshacer</translation>
    </message>
    <message>
        <source>Unrecognized encoding</source>
        <translation>Codificación desconocida </translation>
    </message>
    <message>
        <source>The text encoding %1 used in %2 is not supported.

It will be interpreted as %3 instead, which may result in incorrect text.</source>
        <translation>La codificación de texto %1, empleada en %2 no está soportada.

Será interpretada como %3, lo cual podría dar como resultado un texto incorrecto.</translation>
    </message>
    <message>
        <source>File changed on disk</source>
        <translation>Archivo modificado en disco</translation>
    </message>
    <message>
        <source>%1 has been modified by another program.

Do you want to discard your current changes, and reload the file from disk?</source>
        <translation>%1 ha sido modificado por otro programa.

¿Desea descartar los cambios efectuados y volver a abrir el archivo en disco?</translation>
    </message>
    <message>
        <source>%1 has been modified by another program.

Do you want to proceed with saving this file, overwriting the version on disk?</source>
        <translation>%1 ha sido modificado por otro programa.

¿Quiere conservar el presente archivo y sobreescribir la versión en disco?</translation>
    </message>
    <message>
        <source>Document &quot;%1&quot; was not saved</source>
        <translation>El documento &quot;%1&quot; no ha sido guardado</translation>
    </message>
    <message>
        <source>Text cannot be converted</source>
        <translation>Este texto no se puede convertir</translation>
    </message>
    <message>
        <source>This document contains characters that cannot be represented in the encoding %1.

If you proceed, they will be replaced with default codes. Alternatively, you may wish to use a different encoding (such as UTF-8) to avoid loss of data.</source>
        <translation>Este documento contiene símbolos que no pueden ser representados en la codificación %1.

Si desea continuar, esos símbolos serán reemplazados por los de la codificación predeterminada. Una alternativa consiste en utilizar otro código (por ejemplo, UTF-8) para evitar la pérdida de información.</translation>
    </message>
    <message>
        <source>Cannot read file &quot;%1&quot;:
%2</source>
        <translation>Error de lectura del archivo &quot;%1&quot;:
%2</translation>
    </message>
    <message>
        <source>Cannot write file &quot;%1&quot;:
%2</source>
        <translation>Error de escritura del archivo &quot;%1&quot;:
%2</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <comment>shortcut: Revert</comment>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; loaded</source>
        <translation>Archivo &quot;%1&quot; abierto</translation>
    </message>
    <message>
        <source>%1 is constantly being modified by another program.

Please use &quot;File &gt; Revert to Saved&quot; manually when the external process has finished.</source>
        <translation>El archivo %1 está siendo modificado por otro programa.
Use &quot;Archivo -&gt; Recuperar versión guardada&quot; manualmente cuando el proceso externo haya terminado.</translation>
    </message>
    <message>
        <source>Error writing file</source>
        <translation>Error de escritura del archivo</translation>
    </message>
    <message>
        <source>An error may have occurred while saving the file. You might like to save a copy in a different location.</source>
        <translation>
Ha ocurrido un error al salvar el archivo. Podría guardar una copia en otro lugar.</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; saved</source>
        <translation>Archivo &quot;%1&quot; guardado</translation>
    </message>
    <message>
        <source>untitled-%1.tex</source>
        <translation>texto-%1.tex</translation>
    </message>
    <message>
        <source>%1[*] - %2</source>
        <translation>%1[*] - %2</translation>
    </message>
    <message>
        <source>Line %1 of %2; col %3</source>
        <translation>Línea %1 de %2; сolumna %3</translation>
    </message>
    <message>
        <source>Go to Line</source>
        <translation>Saltar a la línea</translation>
    </message>
    <message>
        <source>Line number:</source>
        <translation>Línea número:</translation>
    </message>
    <message>
        <source>Invalid regular expression</source>
        <translation>Expresión regular errónea</translation>
    </message>
    <message>
        <source>Not found</source>
        <translation>No encontrado</translation>
    </message>
    <message numerus="yes">
        <source>Found %n occurrence(s)</source>
        <translatorcomment>Se encontraron %n casos</translatorcomment>
        <translation>
            <numerusform>%n caso(s) encontrado(s)</numerusform>
            <numerusform>Se encontró %n caso</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n occurrence(s)</source>
        <translation>
            <numerusform>%n caso encontrado</numerusform>
            <numerusform>%n caso encontrados</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n documents</source>
        <translation>
            <numerusform>%n documento</numerusform>
            <numerusform>%n documentos</numerusform>
        </translation>
    </message>
    <message>
        <source>Replaced %1 in %2</source>
        <translation>Se ha reemplazado %1 en %2</translation>
    </message>
    <message numerus="yes">
        <source>Replaced %n occurrence(s)</source>
        <translation>
            <numerusform>%n reemplazo</numerusform>
            <numerusform>%n reemplazos</numerusform>
        </translation>
    </message>
    <message>
        <source>Cannot process unsaved document</source>
        <translation>No se puede compilar un documento sin guardarlo antes</translation>
    </message>
    <message>
        <source>Root document %1 is not readable</source>
        <translation>No se puede leer el documento principal %1</translation>
    </message>
    <message>
        <source>%1 is not properly configured</source>
        <translation>%1 incorrectamente configurado</translation>
    </message>
    <message>
        <source>Unable to execute %1</source>
        <translation>Imposibe ejecutar %1</translation>
    </message>
    <message>
        <source>Abort typesetting</source>
        <translation>Interrumpir compilación</translation>
    </message>
    <message>
        <source>Set engine to &quot;%1&quot;</source>
        <translation>Compilar con &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; not defined</source>
        <translation>Motor de compilación &quot;%1&quot; no definido</translation>
    </message>
    <message>
        <source>No files found</source>
        <translation>Archivos no encontrados</translation>
    </message>
    <message>
        <source>No auxiliary files associated with this document at the moment.</source>
        <translation>No hay ningún archivo auxiliar asociado con este documento.</translation>
    </message>
    <message>
        <source>untitled.tex[*]</source>
        <translation>texto.tex[*]</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Archivo</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Spelling</source>
        <translation>Ortografía</translation>
    </message>
    <message>
        <source>Change Case</source>
        <translation>Invertir caracteres</translation>
    </message>
    <message>
        <source>Typeset</source>
        <translation>Compilar</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Ventana</translation>
    </message>
    <message>
        <source>Console output</source>
        <translation>Consola de salida</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Exhibir</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Auto-indent Mode</source>
        <translation>Modo de sangrado automático</translation>
    </message>
    <message>
        <source>Syntax Coloring</source>
        <translation>Resaltar sintaxis</translation>
    </message>
    <message>
        <source>Smart Quotes</source>
        <translation>Marcas automáticas</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Scripts</translation>
    </message>
    <message>
        <source>Scripting TeXworks</source>
        <translation>Scripts de TeXworks</translation>
    </message>
    <message>
        <source>Typeset Toolbar</source>
        <translation>Barra de herramientas para composición</translation>
    </message>
    <message>
        <source>Edit Toolbar</source>
        <translation>Barra de herramientas para edición</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nuevo</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Abrir...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Guardar como...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <source>Revert to Saved</source>
        <translation>Recuperar versión guardada</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Deshacer</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Rehacer</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Z</source>
        <translation>Ctrl+Shift+Z</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
    <message>
        <source>Find...</source>
        <translation>Buscar...</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Find Again</source>
        <translation>Continuar búsqueda</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Replace...</source>
        <translation>Reemplazar...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Copy to Find</source>
        <translation>Сopiar en Encontrar</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Copy to Replace</source>
        <translation>Сopiar en Reemplazar</translation>
    </message>
    <message>
        <source>Ctrl+Shift+E</source>
        <translation>Ctrl+Shift+E</translation>
    </message>
    <message>
        <source>Go to Line...</source>
        <translation>Saltar a la línea...</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Find Selection</source>
        <translation>Buscar Selección</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Seleccionar todo</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>Font...</source>
        <translation>Fuente...</translation>
    </message>
    <message>
        <source>Indent</source>
        <translation>Poner sangría</translation>
    </message>
    <message>
        <source>Ctrl+]</source>
        <translation>Ctrl+]</translation>
    </message>
    <message>
        <source>Unindent</source>
        <translation>Quitar sangría</translation>
    </message>
    <message>
        <source>Ctrl+[</source>
        <translation>Ctrl+[</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Incluir comentarios</translation>
    </message>
    <message>
        <source>Ctrl+Shift+]</source>
        <translation>Ctrl+Shift+]</translation>
    </message>
    <message>
        <source>Uncomment</source>
        <translation>Borrar comentarios</translation>
    </message>
    <message>
        <source>Ctrl+Shift+[</source>
        <translation>Ctrl+Shift+[</translation>
    </message>
    <message>
        <source>Wrap Lines</source>
        <translation>Ajuste automático de líneas</translation>
    </message>
    <message>
        <source>About TeXworks...</source>
        <translation>Acerca de TeXworks...</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Cascada</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>Mosaico</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Preferencias...</translation>
    </message>
    <message>
        <source>Go to Preview</source>
        <translation>Previsualización</translation>
    </message>
    <message>
        <source>Ctrl+&apos;</source>
        <translation>Ctrl+&apos;</translation>
    </message>
    <message>
        <source>Ctrl+\</source>
        <translation>Ctrl+\</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>Nuevo a partir de Plantilla...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>Show Selection</source>
        <translation>Mostrar Selección</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>ALL UPPERCASE</source>
        <translation>TODAS MAYÚSCULAS</translation>
    </message>
    <message>
        <source>all lowercase</source>
        <translation>todas minúsculas</translation>
    </message>
    <message>
        <source>Balance Delimiters</source>
        <translation>Emparejar delimitadores</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>Página oficial de TeXworks</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>Escribir a la lista de usuarios</translation>
    </message>
    <message>
        <source>Side by Side</source>
        <translation>Lado a Lado</translation>
    </message>
    <message>
        <source>Place on Left</source>
        <translation>Colocar a la izquierda</translation>
    </message>
    <message>
        <source>Place on Right</source>
        <translation>Colocar a la derecha</translation>
    </message>
    <message>
        <source>Replace Again</source>
        <translation>Reemplazar otra vez</translation>
    </message>
    <message>
        <source>Ctrl+Shift+R</source>
        <translation>Ctrl+Shift+R</translation>
    </message>
    <message>
        <source>Remove Aux Files...</source>
        <translation>Borrar archivos auxiliares...</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>Salir de TeXworks</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Toggle Case</source>
        <translation>Invertir caracteres</translation>
    </message>
    <message>
        <source>Show Scripts Folder</source>
        <translation>Carpeta de Scripts</translation>
    </message>
    <message>
        <source>Reload Script List</source>
        <translation>Actualizar lista de Scripts</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation>Guardar todos</translation>
    </message>
    <message>
        <source>Ctrl+Alt+S</source>
        <translation>Ctrl+Alt+S</translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation>Administrar Scripts</translation>
    </message>
    <message>
        <source>Auto-Follow Focus</source>
        <translation>Sincronizar cursor</translation>
    </message>
    <message>
        <source>About Scripts...</source>
        <translation>Acerca de Scripts...</translation>
    </message>
    <message>
        <source>Apply to Selection</source>
        <translation>Aplicar a Selección</translation>
    </message>
    <message>
        <source>The program &quot;%1&quot; was not found.</source>
        <translation>Programa &quot;%1&quot; no encontrado.</translation>
    </message>
    <message>
        <source>Searched in directories:</source>
        <translation>Búsqueda en directorios:</translation>
    </message>
    <message>
        <source>Process interrupted by user</source>
        <translation>Proceso interrumpido por el usuario</translation>
    </message>
    <message>
        <source>Typeset</source>
        <comment>menu title</comment>
        <translation>Compilar</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <comment>action</comment>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Hard Wrap...</source>
        <translation>Ajuste de líneas...</translation>
    </message>
    <message>
        <source>Line Numbers</source>
        <translation>Números de línea</translation>
    </message>
    <message>
        <source>Settings and Resources...</source>
        <translation>Configuración y Recursos ...</translation>
    </message>
    <message>
        <source>Reload using selected encoding</source>
        <extracomment>Item in the encoding popup menu</extracomment>
        <translation>Reabrir utilizando la codificación seleccionada</translation>
    </message>
    <message>
        <source>Reloads the current file with the encoding selected from this menu.

The selected encoding replaces the default one and overrides all &quot;%!TEX encoding&quot; lines.</source>
        <extracomment>Tooltip for &quot;Reload using selected encoding&quot;</extracomment>
        <translation>Reabrir el archivo actual con la codificación seleccionada en este menú.

La codificación seleccionada reemplaza la predeterminada y anula todas las líneas &quot;%!TEX encoding&quot;.
</translation>
    </message>
    <message>
        <source>Unsaved changes</source>
        <translation>Cambios sin guardar</translation>
    </message>
    <message>
        <source>The file you are trying to reload has unsaved changes.

Do you want to discard your current changes, and reload the file from disk with the encoding %1?</source>
        <translation>El archivo que intenta reabrir ha sufrido cambios que aún no se han guardado.

¿Desea descartar los cambios efectuados en el archivo y volver a abrirlo desde el disco, ahora con la codificación %1?</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>Limpiar lista de archivos recientes</translation>
    </message>
    <message>
        <source>Abort typesetting?</source>
        <translation>¿Interrumpir la compilación?</translation>
    </message>
    <message>
        <source>A typesetting process is still running and must be stopped before closing this window.
Do you want to stop it now?</source>
        <translation>El proceso de compilación, que aún sigue corriendo, tendría que ser detenido antes de cerrar esta ventana.
¿Desea interrumpirlo ahora?</translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; or &lt;a href=&quot;http://miktex.org/&quot;&gt;MiKTeX&lt;/a&gt; installed on your system to typeset your document.</source>
        <translation>Necesita tener instalada una &lt;b&gt;distribución TeX&lt;/b&gt; como &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt;
o &lt;a href=&quot;http://miktex.org/&quot;&gt;MiKTeX&lt;/a&gt; en su sistema para compilar el documento.</translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://www.tug.org/mactex/&quot;&gt;MacTeX&lt;/a&gt; installed on your system to typeset your document.</source>
        <translation>Necesita tener instalada una &lt;b&gt;distribución TeX&lt;/b&gt; como &lt;a href=&quot;http://www.tug.org/mactex/&quot;&gt;MacTeX&lt;/a&gt; en su sistema para compilar el documento.</translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; installed on your system to typeset your document. On most systems such a TeX distribution is available as prebuilt package.</source>
        <translation>Necesita tener instalada una &lt;b&gt;distribución TeX&lt;/b&gt; como &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; en su sistema para compilar el documento. Para la mayoría de los sistemas operativos existe una distribución TeX como paquete precompilado.</translation>
    </message>
    <message>
        <source>When a TeX distribution is installed you may need to tell TeXworks where to find it in Edit -&gt; Preferences -&gt; Typesetting.</source>
        <translation>Si ya cuenta con una distribución TeX debidamente instalada, puede que falte indicarle a TeXworks, mediante Editar -&gt; Preferencias -&gt; Compilación, donde localizarla exactamente.</translation>
    </message>
    <message>
        <source>Check the configuration of the %1 tool and the path settings in the Preferences dialog.</source>
        <translation>Revise la configuración de la herramienta %1, así como la &quot;Localizacion de TeX y programas relativos&quot; en la pestaña Preferencias.</translation>
    </message>
    <message>
        <source>Hide Console Output</source>
        <translation>Ocultar consola de salida</translation>
    </message>
    <message>
        <source>Layout Problem</source>
        <translation>Error de diseño</translation>
    </message>
    <message>
        <source>A problem occured while laying out the loaded document in the editor. This is caused by an issue in the underlying Qt framework and can cause TeXworks to crash under certain circumstances. The symptoms of this problem are hidden or overlapping lines. To work around this, please try one of the following:
 -) Turn syntax highlighting off and on
 -) Turn line numbers off and on
 -) Resize the window

We are sorry for the inconvenience.</source>
        <translation>Se produjo un problema al desplegar el documento en el editor. Este error obedece a un problema con Qt, el cual puede ocasionar que TeXworks deje de funcionar en ciertas circunstancias. Los síntomas de este problema se muestran como líneas ocultas o sobrepuestas. Para sortear este problema, realice alguna de las siguientes acciones:
  -) Active y desactive el resaltado de sintaxis
  -) Active y desactive la numeración de líneas
  -) Cambie el tamaño de la ventana

Ofrecemos disculpas por las molestias ocasionadas.</translation>
    </message>
    <message>
        <source>Show Console Output</source>
        <translation>Mostrar consola de salida</translation>
    </message>
    <message>
        <source>Write UTF-8 byte order mark</source>
        <translation>Escribir la etiqueta UTF-8</translation>
    </message>
</context>
<context>
    <name>TeXHighlighter</name>
    <message>
        <source>default</source>
        <translatorcomment>estándar</translatorcomment>
        <translation>estándar</translation>
    </message>
</context>
<context>
    <name>TemplateDialog</name>
    <message>
        <source>New File using Template</source>
        <translation>Nuevo documento a partir de Plantilla</translation>
    </message>
    <message>
        <source>Choose template for the new document:</source>
        <translation>Seleccionar Plantilla para el nuevo documento:</translation>
    </message>
</context>
<context>
    <name>ToolConfig</name>
    <message>
        <source>Select program file</source>
        <translation>Seleccionar programa</translation>
    </message>
    <message>
        <source>Invalid program</source>
        <translation>Programa incorrecto</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; is not executable!</source>
        <translation>¡El archivo &apos;%1&apos; no es ejecutable!</translation>
    </message>
    <message>
        <source>NewArgument</source>
        <translation>Nuevo Parámetro</translation>
    </message>
</context>
<context>
    <name>ToolConfigDialog</name>
    <message>
        <source>Tool Configuration</source>
        <translation>Herramienta para Configuración</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <source>Program:</source>
        <translation>Programa:</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Examinar...</translation>
    </message>
    <message>
        <source>Arguments:</source>
        <translation>Parámetros:</translation>
    </message>
    <message>
        <source>View PDF after running</source>
        <translation>Exhibir el PDF al terminar ejecución</translation>
    </message>
</context>
</TS>
